@@ -21,7 +21,7 @@
   while(TRUE)
   {
    if(iter>=steps) return(res)
-   if(iter>=maxiter) stop("maxiter reached")
+   if(iter>=maxiter) warning("maxiter reached")
    iter<-iter+1
    sqrtV<-mat.sqrt(V)
    A <- solve(sqrtV)
@@ -43,7 +43,7 @@
   while(TRUE)
  {
    if(iter>=steps) return(res)
-   if(iter>=maxiter) stop("maxiter reached")
+   if(iter>=maxiter) warning("maxiter reached")
    iter<-iter+1
    sqrtV<-mat.sqrt(V)
    Q<-signranks(X%*%solve(sqrtV))
